@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -13,9 +13,7 @@ EditorWidget::EditorWidget(QWidget *parent)
 {
 }
 
-EditorWidget::~EditorWidget()
-{
-}
+EditorWidget::~EditorWidget() = default;
 
 void EditorWidget::insertFile(const QString &filename)
 {
